@@ -10,6 +10,8 @@
 
 package org.gnu.gtk.event;
 
+import org.gnu.glib.EventType;
+
 /**
   * This event is used to identify when a FontButton receives an event
  * 
@@ -17,7 +19,7 @@ package org.gnu.gtk.event;
  */
 public class FontButtonEvent extends GtkEvent {
 
-	public static class Type extends GtkEventType {
+	public static class Type extends EventType {
 		private Type(int id, String name) {
 			super(id, name);
 		}
@@ -33,7 +35,7 @@ public class FontButtonEvent extends GtkEvent {
 	 * @param source
 	 * @param type
 	 */
-	public FontButtonEvent(Object source, GtkEventType type) {
+	public FontButtonEvent(Object source, EventType type) {
 		super(source, type);
 	}
 
