@@ -14,18 +14,20 @@
 
 package org.gnu.gtk.event;
 
+import org.gnu.glib.EventType;
+
 /**
- * An event thrown when a cell has been selected in a {@link org.gnu.gtk.TreeView} widget. 
+ * An event generated when a column header in a {@link org.gnu.gtk.TreeView} widget has been clicked.
  */
 public class TreeViewColumnEvent extends GtkEvent {
 
-	public static class Type extends GtkEventType{
+	public static class Type extends EventType{
 		private Type(int id, String name){
 			super(id, name);
 		}
 
 		/**
-		 * This event indicates that the menu item has been activated.
+		 * This event indicates that the column header has been clicked.
 		 */
 		public static final Type CLICKED = new Type(1, "CLICKED");
 	}
