@@ -9,6 +9,7 @@
 
 package org.gnu.pango;
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 
 /**
  * The PangoRectangle structure represents a rectangle. It is frequently used to
@@ -17,7 +18,7 @@ import org.gnu.glib.Boxed;
 public class Rectangle extends Boxed 
 {
 
-	protected Rectangle(int handle){
+	protected Rectangle(Handle handle){
 		this.handle = handle;
 	}
 
@@ -52,10 +53,10 @@ public class Rectangle extends Boxed
     /****************************************
      * BEGINNING OF GENERATED CODE
      ****************************************/
-    native static final protected int getX (int obj);
-    native static final protected int getY (int obj);
-    native static final protected int getWidth (int obj);
-    native static final protected int getHeight (int obj);
+    native static final protected int getX (Handle obj);
+    native static final protected int getY (Handle obj);
+    native static final protected int getWidth (Handle obj);
+    native static final protected int getHeight (Handle obj);
     /****************************************
      * END OF GENERATED CODE
      ****************************************/
